@@ -57,12 +57,13 @@ class AbstractMaterial(object):
         if len(self._useful_kwargs) != self._nbr_useful_kwargs:
             raise Ex(
                 ('Number of input parameters has to be {nbr}.\n'
-                 'Note: Isotropic material is defined by {nbr} parameters.\n'
+                 'Note: {mat} is defined by {nbr} parameters.\n'
                  'Given arguments are:{kwargs}\n'
                  'Identified primary input parameters are:{useful}\n').format(
                                                     kwargs=kwargs,
                                                     useful=self._useful_kwargs,
-                                                    nbr=self._nbr_useful_kwargs
+                                                    nbr=self._nbr_useful_kwargs,
+                                                    mat=type(self)
                                                     )
                 )
 
@@ -439,7 +440,7 @@ class Isotropic(AbstractMaterial):
                      'c44_voigt', 'c55_voigt', 'c66_voigt',
                      'c2323', 'c1313', 'c1212'],
             'E':    ['e', 'youngs_modulus', 'elastic_modulus', ],
-            'nu':   ['nu', 'poisson', 'poisson_ratio', ],
+            'nu':   ['nu', 'poisson', 'poisson_ratio', 'v'],
             'la':   ['la', 'lambd', 'first_lame', 'lame_1',
                      'c23_voigt', 'c13_voigt', 'c12_voigt',
                      'c32_voigt', 'c31_voigt', 'c21_voigt',
